@@ -3,6 +3,10 @@
 ##' If \code{\link[testthat]{testthat}} is available, run the unit tests and
 ##' display the results.
 ##'
+##' @param standalone run the unit test on their own, e.g. from the console
+##'   (`TRUE`) or within testthat tests (`FALSE`), e.g. via `devtools::test()`
+##' @param reporter the reporter to use, defaults to [testthat::ProgressReporter]
+##'
 ##' @rdname unittests
 ##' @return Invisibly returns a data frame with the test results
 ##'
@@ -15,7 +19,7 @@
 ##'
 ##' hy.unittest ()
 ##'
-hy.unittest <- function (){
+hy.unittest <- function (standalone = TRUE, reporter = "progress"){
   if (!requireNamespace("testthat", quietly=TRUE)) {
     warning("testthat required to run the unit tests.")
     return(NA)
@@ -26,19 +30,12 @@ hy.unittest <- function (){
   tests <- eapply(env = getNamespace ("hyperSpec"), FUN = get.test, all.names=TRUE)
   tests <- tests [! sapply (tests, is.null)]
 
-  reporter <- SummaryReporter$new()
-  lister <- ListReporter$new()
-  reporter <- MultiReporter$new(reporters = list(reporter, lister))
-
-  with_reporter(reporter = reporter, start_end_reporter = TRUE, {
-    for (t in seq_along(tests)){
-      lister$start_file(names (tests [t]))
-      tests [[t]] ()
-    }
-    get_reporter()$.end_context()
-  })
-
-  invisible(lister$get_results())
+  if (standalone) {
+    with_reporter(reporter = reporter, start_end_reporter = TRUE,
+                  for (t in tests) t())
+  } else {
+    for (t in tests) t()
+  }
 }
 
 ##' @noRd
@@ -47,7 +44,7 @@ hy.unittest <- function (){
     attr (f, "test") <- value
     f
   }
-  
+
   skip_if_not_fileio_available <- function () {
     skip_if_not (file.exists("fileio"), message = "file import test files not installed")
   }
